@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://imagemagick.org/script/license.php
+    https://imagemagick.org/license/
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,20 +30,20 @@ extern "C" {
 #define MagickLibVersion  0x69D
 #define MagickLibVersionText  "6.9.13"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-35"
+#define MagickLibAddendum  "-39 (Beta)"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
 #define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "6.9.13"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-35"
+#define MagickppLibAddendum  "-39 (Beta)"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickGitRevision  "18971"
-#define MagickReleaseDate  "2025-12-07"
+#define MagickGitRevision  "19085"
+#define MagickReleaseDate  "2026-02-08"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeLicense  \
-  "https://imagemagick.org/script/license.php"
+  "https://imagemagick.org/license/"
 #define MagickAuthoritativeURL  "https://legacy.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
